{ nixpkgs ? import <nixpkgs> { }, pythonPkgs ? nixpkgs.pkgs.python39Packages }:

let
  inherit (nixpkgs) pkgs;
  inherit pythonPkgs;

  selfprivacy-graphql-api =
    { buildPythonPackage
    , fetchPypi
    , setuptools
    , portalocker
    , pytz
    , pytest
    , pytest-mock
    , pytest-datadir
    , huey
    , gevent
    , mnemonic
    , pydantic
    , typing-extensions
    , strawberry_graphql
    , psutil
    , fastapi
    , uvicorn
    , redis
    }:
    pythonPkgs.buildPythonApplication rec {
      pname = "selfprivacy-graphql-api";
      version = "2.0.10";
      src = builtins.fetchGit {
        url = "https://git.selfprivacy.org/SelfPrivacy/selfprivacy-rest-api.git";
        rev = "9ee0240bbd2056b5057d29a0d919dac3635dcb92";
        ref = "redis/connection-pool";
      };
      propagatedBuildInputs = [
        setuptools
        portalocker
        pytz
        pytest
        pytest-mock
        pytest-datadir
        huey
        gevent
        mnemonic
        pydantic
        typing-extensions
        strawberry_graphql
        psutil
        fastapi
        uvicorn
        redis
      ];
      meta = {
        description = ''
          SelfPrivacy Server Management API
        '';
      };
      passthru = {
        pythonPath = pythonPkgs.makePythonPath propagatedBuildInputs;
      };
    };
  drv = pythonPkgs.callPackage selfprivacy-graphql-api { };
in
drv
